@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2020 The pyXem developers
+# Copyright 2016-2021 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -25,9 +25,8 @@ from skimage.draw import polygon
 
 from hyperspy.components1d import Gaussian
 
-import pyxem.dummy_data.make_diffraction_test_data as mdtd
-from pyxem.signals.differential_phase_contrast import DPCSignal2D
-from pyxem.signals.diffraction2d import Diffraction2D, LazyDiffraction2D
+from pyxem.dummy_data import make_diffraction_test_data as mdtd
+from pyxem.signals import DPCSignal2D, Diffraction2D, LazyDiffraction2D
 
 
 def get_disk_shift_simple_test_signal(lazy=False):
@@ -46,12 +45,12 @@ def get_disk_shift_simple_test_signal(lazy=False):
 
     Examples
     --------
-    >>> s = ps.dummy_data.get_disk_shift_simple_test_signal()
+    >>> s = pxm.dummy_data.get_disk_shift_simple_test_signal()
     >>> s.plot()
 
     Load as lazy
 
-    >>> s = ps.dummy_data.get_disk_shift_simple_test_signal(lazy=True)
+    >>> s = pxm.dummy_data.get_disk_shift_simple_test_signal(lazy=True)
 
     """
     disk_x, disk_y = np.mgrid[22:28:20j, 22:28:20j]
@@ -87,12 +86,12 @@ def get_holz_simple_test_signal(lazy=False):
 
     Examples
     --------
-    >>> s = ps.dummy_data.get_holz_simple_test_signal()
+    >>> s = pxm.dummy_data.get_holz_simple_test_signal()
     >>> s.plot()
 
     Load as lazy
 
-    >>> s = ps.dummy_data.get_holz_simple_test_signal(lazy=True)
+    >>> s = pxm.dummy_data.get_holz_simple_test_signal(lazy=True)
 
     """
     ring_x, ring_y = np.mgrid[24:26:20j, 24:26:20j]
@@ -131,12 +130,12 @@ def get_holz_heterostructure_test_signal(lazy=False):
 
     Example
     -------
-    >>> s = ps.dummy_data.get_holz_heterostructure_test_signal()
+    >>> s = pxm.dummy_data.get_holz_heterostructure_test_signal()
     >>> s.plot()
 
     Load as lazy
 
-    >>> s = ps.dummy_data.get_holz_heterostructure_test_signal(lazy=True)
+    >>> s = pxm.dummy_data.get_holz_heterostructure_test_signal(lazy=True)
 
     """
     probe_size_x, probe_size_y = 40, 40
@@ -187,11 +186,11 @@ def get_dead_pixel_signal(lazy=False):
 
     Example
     -------
-    >>> s = ps.dummy_data.get_dead_pixel_signal()
+    >>> s = pxm.dummy_data.get_dead_pixel_signal()
 
     Lazy signal
 
-    >>> s_lazy = ps.dummy_data.get_dead_pixel_signal(lazy=True)
+    >>> s_lazy = pxm.dummy_data.get_dead_pixel_signal(lazy=True)
 
     """
     data = mdtd.MakeTestData(size_x=128, size_y=128, default=False, blur=True)
@@ -218,11 +217,11 @@ def get_hot_pixel_signal(lazy=False):
 
     Example
     -------
-    >>> s = ps.dummy_data.get_hot_pixel_signal()
+    >>> s = pxm.dummy_data.get_hot_pixel_signal()
 
     Lazy signal
 
-    >>> s_lazy = ps.dummy_data.get_hot_pixel_signal(lazy=True)
+    >>> s_lazy = pxm.dummy_data.get_hot_pixel_signal(lazy=True)
 
     """
     data = mdtd.MakeTestData(size_x=128, size_y=128, default=False, blur=True)
@@ -247,7 +246,7 @@ def get_simple_dpc_signal():
 
     Example
     -------
-    >>> s = ps.dummy_data.get_simple_dpc_signal()
+    >>> s = pxm.dummy_data.get_simple_dpc_signal()
 
     """
     data = np.mgrid[-5:5:100j, -5:5:100j]
@@ -268,7 +267,7 @@ def get_stripe_pattern_dpc_signal():
 
     Example
     -------
-    >>> s = ps.dummy_data.get_stripe_pattern_dpc_signal()
+    >>> s = pxm.dummy_data.get_stripe_pattern_dpc_signal()
 
     """
     data = np.zeros((2, 100, 50))
@@ -294,12 +293,12 @@ def get_square_dpc_signal(add_ramp=False):
 
     Examples
     --------
-    >>> s = ps.dummy_data.get_square_dpc_signal()
+    >>> s = pxm.dummy_data.get_square_dpc_signal()
     >>> s.plot()
 
     Adding a ramp
 
-    >>> s = ps.dummy_data.get_square_dpc_signal(add_ramp=True)
+    >>> s = pxm.dummy_data.get_square_dpc_signal(add_ramp=True)
     >>> s.plot()
 
     """
@@ -329,8 +328,7 @@ def get_square_dpc_signal(add_ramp=False):
 
 
 def get_fem_signal(lazy=False):
-    """Get a 2D signal that approximates a fluctuation electron microscopy
-    (FEM) dataset.
+    """Get a 2D signal approximating a fluctuation electron microscopy (FEM) dataset.
 
     Parameters
     ----------
@@ -343,7 +341,7 @@ def get_fem_signal(lazy=False):
 
     Examples
     --------
-    >>> s = ps.dummy_data.get_fem_signal()
+    >>> s = pxm.dummy_data.get_fem_signal()
     >>> s.plot()
 
     """
@@ -422,8 +420,7 @@ def get_fem_signal(lazy=False):
 
 
 def get_simple_fem_signal(lazy=False):
-    """Get a 2D signal that approximates a very small fluctuation electron
-    microscopy (FEM) dataset.
+    """2D signal approximating a very small fluctuation electron microscopy (FEM) dataset.
 
     Parameters
     ----------
@@ -436,7 +433,7 @@ def get_simple_fem_signal(lazy=False):
 
     Examples
     --------
-    >>> s = ps.dummy_data.get_simple_fem_signal()
+    >>> s = pxm.dummy_data.get_simple_fem_signal()
     >>> s.plot()
 
     """
@@ -517,8 +514,7 @@ def get_simple_fem_signal(lazy=False):
 
 
 def get_generic_fem_signal(probe_x=2, probe_y=2, image_x=50, image_y=50, lazy=False):
-    """Get a 2D signal that approximates a fluctuation electron
-    microscopy (FEM) dataset with user defined dimensions.
+    """2D signal approximating a fluctuation electron microscopy (FEM) dataset with user defined dimensions.
 
     Parameters
     ----------
@@ -539,7 +535,7 @@ def get_generic_fem_signal(probe_x=2, probe_y=2, image_x=50, image_y=50, lazy=Fa
 
     Examples
     --------
-    >>> s = ps.dummy_data.get_generic_fem_signal(probe_x=5, probe_y=10,
+    >>> s = pxm.dummy_data.get_generic_fem_signal(probe_x=5, probe_y=10,
     ...     image_x=25, image_y=30, lazy=False)
     >>> s.plot()
 
@@ -629,7 +625,7 @@ def get_cbed_signal():
 
     Example
     -------
-    >>> s = ps.dummy_data.get_cbed_signal()
+    >>> s = pxm.dummy_data.get_cbed_signal()
     >>> s.plot()
 
     """
@@ -676,7 +672,7 @@ def get_simple_ellipse_signal_peak_array():
 
     Examples
     --------
-    >>> s, peak_array = ps.dummy_data.get_simple_ellipse_signal_peak_array()
+    >>> s, peak_array = pxm.dummy_data.get_simple_ellipse_signal_peak_array()
     >>> s.add_peak_array_as_markers(peak_array, color='blue', size=30)
 
     """
@@ -699,7 +695,7 @@ def get_nanobeam_electron_diffraction_signal():
 
     Example
     -------
-    >>> s = ps.dummy_data.get_nanobeam_electron_diffraction_signal()
+    >>> s = pxm.dummy_data.get_nanobeam_electron_diffraction_signal()
     >>> s.plot()
 
     """
@@ -712,21 +708,21 @@ def get_nanobeam_electron_diffraction_signal():
     di1.rotation = 10
     di2 = di0.copy()
     di2.rotation = -10
-    position_array0 = np.zeros((50, 50), dtype=np.bool)
 
+    position_array0 = np.zeros((50, 50), dtype=np.bool)
     r = np.array([15, 15, 0, 0])
     c = np.array([0, 15, 31, 0])
     rr, cc = polygon(r, c)
     position_array0[rr, cc] = True
 
     r = np.array([10, 19, 29, 40])
-    c = np.array([50, 35, 35, 50])
+    c = np.array([49, 35, 35, 49])
     rr, cc = polygon(r, c)
     position_array0[rr, cc] = True
-    position_array1 = np.zeros((50, 50), dtype=np.bool)
 
-    r = np.array([32, 41, 41, 50, 50])
-    c = np.array([0, 18, 50, 50, 0])
+    position_array1 = np.zeros((50, 50), dtype=np.bool)
+    r = np.array([32, 41, 41, 49, 49])
+    c = np.array([0, 18, 49, 49, 0])
     rr, cc = polygon(r, c)
     position_array1[rr, cc] = True
 
